import { jsx as _jsx, Fragment as _Fragment } from "react/jsx-runtime";
import { components, renderClassName } from 'fastui';
export const Pagination = (props) => {
    const { page, pageCount } = props;
    if (pageCount === 1)
        return null;
    const links = [
        {
            Display: () => _jsx("span", { "aria-hidden": "true", children: "\u00AB" }),
            ariaLabel: 'Previous',
            locked: page === 1,
            page: page - 1,
        },
        {
            Display: () => _jsx(_Fragment, { children: "1" }),
            locked: page === 1,
            active: page === 1,
            page: 1,
        },
    ];
    if (page > 4) {
        links.push({ Display: () => _jsx(_Fragment, { children: "..." }) });
    }
    for (let p = page - 2; p <= page + 2; p++) {
        if (p <= 1 || p >= pageCount)
            continue;
        links.push({
            Display: () => _jsx(_Fragment, { children: p }),
            locked: page === p,
            active: page === p,
            page: p,
        });
    }
    if (page < pageCount - 3) {
        links.push({ Display: () => _jsx(_Fragment, { children: "..." }) });
    }
    links.push({
        Display: () => _jsx(_Fragment, { children: pageCount }),
        locked: page === pageCount,
        page: pageCount,
    });
    links.push({
        Display: () => _jsx("span", { "aria-hidden": "true", children: "\u00BB" }),
        ariaLabel: 'Next',
        locked: page === pageCount,
        page: page + 1,
    });
    return (_jsx("nav", { "aria-label": "Pagination", children: _jsx("ul", { className: "pagination justify-content-center", children: links.map((link, i) => (_jsx(PaginationLink, { ...link }, i))) }) }));
};
const PaginationLink = ({ Display, ariaLabel, locked, active, page }) => {
    if (!page) {
        return (_jsx("li", { className: "page-item", children: _jsx("span", { className: "page-link px-2 text-muted", children: _jsx(Display, {}) }) }));
    }
    const className = renderClassName({ 'page-link': true, disabled: locked && !active, active });
    let onClick;
    if (page === 1) {
        onClick = { type: 'go-to', query: {} };
    }
    else {
        onClick = { type: 'go-to', query: { page } };
    }
    return (_jsx("li", { className: "page-item", children: _jsx(components.LinkRender, { onClick: onClick, className: className, locked: locked || active, ariaLabel: ariaLabel, children: _jsx(Display, {}) }) }));
};
