import { jsx as _jsx, Fragment as _Fragment } from "react/jsx-runtime";
import { createContext, useCallback, useContext, useState } from 'react';
import { ErrorComp } from '../components';
import { useCustomRender } from './config';
export const DisplayError = ({ title, description, statusCode, children }) => {
    const props = {
        title,
        description,
        statusCode,
        children,
        type: 'Error',
    };
    const CustomRenderComp = useCustomRender(props);
    if (CustomRenderComp) {
        return _jsx(CustomRenderComp, {});
    }
    else {
        return _jsx(ErrorComp, { ...props });
    }
};
export const ErrorContext = createContext({
    error: null,
    setError: () => null,
});
const MaybeError = ({ children }) => {
    const { error } = useContext(ErrorContext);
    if (error) {
        return _jsx(DisplayError, { ...error, children: children });
    }
    else {
        return _jsx(_Fragment, { children: children });
    }
};
export const ErrorContextProvider = ({ children }) => {
    const [error, setErrorState] = useState(null);
    const setError = useCallback((error) => {
        if (error) {
            console.warn('setting error:', error);
        }
        setErrorState(error);
    }, [setErrorState]);
    return (_jsx(ErrorContext.Provider, { value: { error, setError }, children: _jsx(MaybeError, { children: children }) }));
};
